import { detectScriptInjection } from '../detectors/scriptInjectionDetector';
import {
  detectSQLInjection,
  isSQLSentence,
} from '../detectors/sqlInjectionDetector';
import { detectXSS } from '../detectors/xssDetector';
import { ScanOptions } from '../scan/interfaces/ITScanOptions';

export function checkDetectors(
  value: string,
  key: string,
  issues: string[],
  options: ScanOptions,
  isKey: boolean = false,
): void {
  const { detectSentences, detectReservedWords } = options;
  if (detectSentences && isSQLSentence(value)) {
    issues.push(
      `SQL Sentence detected in ${isKey ? 'key' : key} "${key}": "${value}".`,
    );
  }
  if (detectReservedWords && detectSQLInjection(value)) {
    issues.push(
      `SQL Injection detected in ${isKey ? 'key' : key} "${key}": "${value}".`,
    );
  }
  if (detectXSS(value)) {
    issues.push(`XSS detected in ${isKey ? 'key' : key} "${key}": "${value}".`);
  }
  if (detectScriptInjection(value)) {
    issues.push(
      `Script Injection detected in ${
        isKey ? 'key' : key
      } "${key}": "${value}".`,
    );
  }
}
